@@ -175,7 +175,11 @@ sub new {
 
     # decode as UTF-8
     for my $key ( qw(extract extract_date_format) ) {
-        $data->{$key} = decode("UTF-8", $data->{$key});
+	if (ref $data->{$key} && ref $data->{$key} eq 'ARRAY') {
+	    $data->{$key} = [ map decode("UTF-8", $_), @{$data->{$key}} ];
+	} else {
+	    $data->{$key} = decode("UTF-8", $data->{$key});
+	}
     }
 
     bless {%$data, base => $base }, $class;
