@@ -2,26 +2,14 @@ package Plagger::Plugin::Filter::YahooBlogSearchPermalink;
 use strict;
 use base qw( Plagger::Plugin );
 
-use URI;
-
-sub register {
-    my($self, $context) = @_;
-    $context->register_hook(
-        $self,
-        'update.entry.fixup' => \&filter,
-    );
+sub init {
+    my $self = shift;
+    $self->SUPER::init(@_);
+    Plagger->context->log(warn => $self->class_id . " is now deprecated. Use Filter::TruePermalink");
+    Plagger->context->autoload_plugin('Filter::TruePermalink');
 }
 
-sub filter {
-    my($self, $context, $args) = @_;
-
-    my $entry = $args->{entry};
-    my $permalink = $entry->permalink;
-    if ($permalink =~ s!^http://rd\.yahoo\.co\.jp/rss/l/blogsearch/search/\*!!) {
-        $entry->permalink($permalink);
-        $context->log(info => "Permalink rewritten to $permalink");
-    }
-}
+sub register { }
 
 1;
 
@@ -33,6 +21,8 @@ Plagger::Plugin::Filter::YahooBlogSearchPermalink - Fix Yahoo! Blog Search perma
 
 =head1 SYNOPSIS
 
+B<THIS MODULE IS DEPRECATED. USE Filter::TruePermalink INSTEAD>
+
   - module: Filter::YahooBlogSearchPermalink
 
 =head1 DESCRIPTION
